@@ -2,10 +2,12 @@
 #define CATDOC_H
 
 #include <stdio.h>
+#include <ctype.h>
 /*
  * User customization
  *
  */
+
 #ifdef __unix
 #ifndef USERC
 #define USERRC ".catdocrc"
@@ -49,6 +51,7 @@ char *add_exe_path(const char* name);
 #endif
 #define PARAGRAPH_BUFFER 262144
 #define FILE_BUFFER 262144
+#define PATH_BUF_SIZE 1024
 #else
 /* if it is not unix, its probably DOS*/
 #define TARGET_CHARSET "cp866"
@@ -56,6 +59,8 @@ char *add_exe_path(const char* name);
 #define REPL_EXT ".rpl"
 #define PARAGRAPH_BUFFER 16384
 #define FILE_BUFFER  32256
+#define PATH_BUF_SIZE 80 
+/* no use for pathnames longer than 80 chars in fat FS */
 #endif
 #ifndef SOURCE_CHARSET
 #define SOURCE_CHARSET "cp1251"
@@ -63,6 +68,9 @@ char *add_exe_path(const char* name);
 #ifndef UNKNOWN_CHAR
 #define UNKNOWN_CHAR '?'
 #endif
+/* Buffer for single line. Should be greater than wrap margin +
+  longest substitution sequence */
+#define LINE_BUF_SIZE 512
 /*   Default value for wrap margin */
 #ifndef WRAP_MARGIN
 #define WRAP_MARGIN 72
@@ -74,6 +82,11 @@ extern  int wrap_margin;
  * to all files in the program
  */
 
+#ifdef __TURBOC__
+#undef isspace
+#define isspace(c) ((unsigned char)(c) <=32)
+#endif
+
 /* Structure to store UNICODE -> target charset mappings */
 /* array of 256 pointers (which may be null) to arrays of 256 short ints
    which contain 8-bit character codes or -1 if no matching char */
@@ -113,10 +126,12 @@ extern char* map_char(int unicode_char);
 extern char* map_path, *charset_path;
 extern int signature_check;
 extern int unknown_as_hex;
-void find_file(char *full_path,const char *name, const char *path);
+char *find_file(char *name, const char *path);
+char *stradd(const char *s1, const char *s2);
 void read_config_file(const char *filename);
-SUBSTMAP read_substmap(const char* filename);
-
+SUBSTMAP read_substmap(char* filename);
+extern int longest_sequence;/* for checking which value of wrap_margin
+                             can cause buffer overflow*/
 char *map_subst(SUBSTMAP map,int uc);
 
 void check_charset(char **filename,const char *charset);
